{ pkgs, ownLib }:

with pkgs; [
  nix
  cacert
  nvd

  # System tools
  dmenu
  gnome.gnome-screenshot

  networkmanager_dmenu
  i3blocks
  st
  ncdu
  tree
  (callPackage ./packages/rst2pdf { })
  (callPackage ./packages/sitediff { })

  borgbackup
  keepassxc
  # Git itself is installed via git module
  git-crypt

  rclone

  libreoffice

  # Dev tools
  litecli
  sqlite
  mycli
  mkcert # TODO: Create own wrapper script to create new certs
  tig
  universal-ctags
  silver-searcher
  curl
  wget
  kcachegrind
  geckodriver

  docker-compose

  # In order to pull binaries from their.
  # E.g. phps: https://github.com/fossar/nix-phps#how-to-use
  cachix

  # Coding / Neovim
  # Does not provide any autocompletion yet, don't know why
  # Use in conjuncion with https://github.com/autozimu/LanguageClient-neovim
  # rnix-lsp

  # For fzf, looks like it is missing right now there
  # .nix-profile/bin/fzf-tmux: line 183: bc: command not found
  bc

  # Communication
  signal-desktop
  thunderbird

  # Media
  vlc
  gtkpod
  handbrake
  # Typical download looks like: yt-dlp -S 'res:700,ext:mp4' <url>
  yt-dlp
  spotdl
  # tenacity
  ffmpeg-full # full in order to grab x11
  python39Packages.mutagen
  feh

  gtk-engine-murrine
] ++ (if ownLib.onHikari {} then [
  # hikari

  acpilight # Used to support xbacklight

  (callPackage ./packages/custom/update-nixos-system { })
  # Needs to be installed by ubuntu on ubuntu
  sound-juicer

] else [
  # hikari 2

  (callPackage ./packages/custom/update-ubuntu-system { })
  # TODO: Right now only for Ubuntu (hikari2) system
  (callPackage ./packages/custom/backup { })
]) ++ (callPackage ./packages/custom {
  inherit ownLib;
})
